@@ -146,3 +146,9 @@ Frechet$set("public","initialize",function(shape = 1, scale = 1, minimum = 0,
                    variateForm = "univariate")
   invisible(self)
 })
+
+.distr6$distributions = rbind(.distr6$distributions,
+                              data.table::data.table(ShortName = "Frec", ClassName = "Frechet",
+                                                     Type = "\u211D", ValueSupport = "continuous",
+                                                     VariateForm = "univariate",
+                                                     Package = "distr6"))
