@@ -115,3 +115,9 @@ Gumbel$set("public","initialize",function(location = 0, scale = 1,
                    variateForm = "univariate")
   invisible(self)
 })
+
+.distr6$distributions = rbind(.distr6$distributions,
+                              data.table::data.table(ShortName = "Gumb", ClassName = "Gumbel",
+                                                     Type = "\u211D+", ValueSupport = "continuous",
+                                                     VariateForm = "univariate",
+                                                     Package = "distr6"))
