@@ -35,7 +35,9 @@ test_that("statistics",{
   expect_equal(b$pgf(1), 1)
   expect_equal(b$mode(), 5)
   expect_equal(b$pdf(1), dbinom(1,size=10,0.5))
+  expect_equal(b$pdf(1.8), 0)
   expect_equal(b$cdf(1), pbinom(1,size=10,0.5))
+  expect_equal(b$cdf(1.8), pbinom(1,size=10,0.5))
   expect_equal(b$quantile(0.56), qbinom(0.56,size=10,0.5))
   expect_silent(b$rand(10))
 })
