@@ -21,12 +21,16 @@ test_that("properties & traits",{
 test_that("statistics",{
   expect_equal(emp$mean(), mean(1:10))
   expect_equal(emp$variance(), var(1:10)*9/10)
-  expect_error(emp$skewness())
-  expect_error(emp$kurtosis())
-  expect_error(emp$entropy())
-  expect_error(emp$mgf(1:3))
-  expect_error(emp$pgf(1:3))
-  expect_error(emp$cf(1:3))
+  expect_equal(emp$skewness(), 0)
+  expect_equal(round(emp$kurtosis(), 2), -1.22)
+  expect_equal(round(emp$kurtosis(FALSE), 2), 1.78)
+  expect_equal(round(emp$entropy(), 2), 3.32)
+  expect_equal(emp$mgf(1:2), c(3484.377, 56110211))
+  expect_equal(round(emp$mgf(1),3), 3484.377)
+  expect_equal(emp$pgf(1:2), c(1, 204.6))
+  expect_equal(emp$pgf(2), 204.6)
+  expect_equal(round(emp$cf(1),2), -0.14+0.14i)
+  expect_equal(round(emp$cf(1:2),2), round(c(emp$cf(1), emp$cf(2)), 2))
   expect_equal(emp$mode(), 1:10)
   expect_equal(emp$mode(which = 2), 2)
   expect_equal(emp$pdf(2), 1/10)
