@@ -7,6 +7,20 @@ test_that("constructor",{
   expect_silent(Weibull$new(shape = 2))
   expect_silent(Weibull$new(scale = 2))
   expect_silent(Weibull$new(shape=2.5,scale=1))
+  expect_silent(Weibull$new(shape=2.5,altscale=2))
+  expect_message(Weibull$new(shape=2.5,altscale=2, verbose = T))
+  expect_silent(Weibull$new(shape=2.5,altscale=2,scale = 1))
+  expect_warning(Weibull$new(shape=2.5,altscale=-2))
+
+  expect_equal(Weibull$new(scale = 2)$getParameterValue("scale"), 2)
+  expect_equal(Weibull$new(altscale = 2)$getParameterValue("altscale"), 2)
+  expect_equal(Weibull$new(scale = 2, shape = 5)$getParameterValue("altscale"), 0.03125)
+  expect_equal(round(Weibull$new(altscale = 2, shape = 5)$getParameterValue("scale"),3), 0.871)
+
+  expect_equal(Weibull$new(scale = 3, shape = 5)$setParameterValue(scale = 2)$getParameterValue("altscale"), 0.03125)
+  expect_equal(round(Weibull$new(altscale = 4, shape = 5)$setParameterValue(altscale = 2)$getParameterValue("scale"),3), 0.871)
+
+
 })
 
 test_that("properties & traits",{
